SkillFlux — Data model and logic
================================

Synopsis
--------

This is a Django application encapsulating the SkillFlux method as
data model and accompanying logic. It is designed to be reusable in
projects that intend to employ the SkillFlux method, and are creating
digital tooling to support it.

SkillFlux and information science
---------------------------------

TBA.
